<?php

namespace HCM\FPA\Services;

use Doctrine\ORM\EntityManager;
use HCM\Util\DateUtil;
use HCM\Util\HCMParameters;
use HCM\Util\Repositories;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Error;


class CCTService {
    
    protected $entityManager;
    protected $hcmParameters;
    
    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters, \HCM\FPA\Repository\CCTRepository $CCTRepository) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->CCTRepository = $CCTRepository;
    }
    
    public function novoCCT($nrestruturam, $dtanobasecct, $dtinivigenciacct, $dtfinvigenciacct){
        $cadastrocct = Repositories::FPA_CADASTROCCT;
        
        $novo = new $cadastrocct;
        $novo->setNrestruturam($nrestruturam);
        $novo->setDtanobasecct($dtanobasecct);
        $novo->setDtinivigenciacct($dtinivigenciacct);
        $novo->setDtfinvigenciacct($dtfinvigenciacct);
        $novo->setIdativo('S');
        $novo->setNrorg($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtinclusao(DateUtil::getDataAtual());
        $novo->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $novo->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtultatu(DateUtil::getDataAtual());
        $novo->setCdoperultatu($this->hcmParameters->getCdoperador());
        $novo->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        $novo->setNrcadastrocct(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'FPA_CADASTROCCT', 1, 12, true));
        
        $this->entityManager->persist($novo);
        $this->entityManager->flush();
        
        return $novo;
    }
    
    public function novoItemCCT($nrcadastrocct, $nrtipoitemcct, $dsitemcct, $dslegislacaoitcct, $nrocupacaom, $nrescalatrabm, $nrsitufuncm, $nrtpdemissao, $nreventom, $nrfaixatabfolha, $nrvalorreferenciam,
                                $vrpisoitcct, $vrtetoitcct, $dtiniitemcct, $dtfinitemcct, $vrpercentualitcct, $vritemcct, $dsiniintervalocct, $dsfinintervalocct, $vridademinimacct, $vridademaximacct,
                                $qtdemesesitcct, $qtdeanomincct, $qtdeanomaxcct, $qtdiasestabitcct){
        $itcadastrocct = Repositories::FPA_ITCADASTROCCT;
        
        $novo = new $itcadastrocct;
        $novo->setNrcadastrocct($nrcadastrocct);
        $novo->setNrtipoitemcct($nrtipoitemcct);
        $novo->setDsitemcct($dsitemcct);
        $novo->setDslegislacaoitcct($dslegislacaoitcct);
        $novo->setNrocupacaom($nrocupacaom);
        $novo->setNrescalatrabm($nrescalatrabm);
        $novo->setNrsitufuncm($nrsitufuncm);
        $novo->setNrtpdemissao($nrtpdemissao);
        $novo->setNreventom($nreventom);
        $novo->setNrfaixatabfolha($nrfaixatabfolha);
        $novo->setNrvalorreferenciam($nrvalorreferenciam);
        $novo->setVrpisoitcct($vrpisoitcct);
        $novo->setVrtetoitcct($vrtetoitcct);
        $novo->setDtiniitemcct($dtiniitemcct);
        $novo->setDtfinitemcct($dtfinitemcct);
        $novo->setVrpercentualitcct($vrpercentualitcct);
        $novo->setVritemcct($vritemcct);
        $novo->setDsiniintervalocct($dsiniintervalocct);
        $novo->setDsfinintervalocct($dsfinintervalocct);
        $novo->setVridademinimacct($vridademinimacct);
        $novo->setVridademaximacct($vridademaximacct);
        $novo->setQtdemesesitcct($qtdemesesitcct);
        $novo->setQtdeanomincct($qtdeanomincct);
        $novo->setQtdeanomaxcct($qtdeanomaxcct);
        $novo->setQtdiasestabitcct($qtdiasestabitcct);
        $novo->setNrorg($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtinclusao(DateUtil::getDataAtual());
        $novo->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $novo->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtultatu(DateUtil::getDataAtual());
        $novo->setCdoperultatu($this->hcmParameters->getCdoperador());
        $novo->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        $novo->setNritcadastrocct(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'FPA_ITCADASTROCCT', 1, 12, true));
        
        $this->entityManager->persist($novo);
        $this->entityManager->flush();
        
        return $novo;
    }
    
    public function novoBeneficioCCT(
        $nrcadastrocct, $nrtpbeneficio, $nridademaxsubfilhos, $sexosubsidiofilho, $nridademaxsubdep, $sexosubsidiodep, $nrevetitularvinc, $nrtipoparticipatitular, $nrtabfaixasaltit, $vrtitularsind, $vrtetotitularsind,
        $vrpisotitularsind, $nrevedepevinc, $nrtipoparticipadep, $nrtabfaixasaldep, $vrdepsind, $vrpisodepsind, $vrtetodepsind, $idativo, $nreventomensa, $nreventomensadep, $vrtetotitularmens, $vrpisotitularmens, 
        $vrlinearbeneficio, $vrlinearbeneficiodep, $idpropadmis, $idpropresc, $qtdiasminmes, $qtdiasmaxfaltas, $qtdiasmaxatest, $qtmesmaxafast, $vrmultiplicador, $dsvinculoempreg, $dsincidevento, $vrfixacresdesc, 
        $vrperacrescdesc, $idnaogerbenvincexp, $idnaogerabenperexp, $idnaogerabenresc, $vrparticipatitular, $vrpisotitular, $vrtetotitular, $vrparticipadepe, $vrpisodep, $vrtetodep, $qtmaxhsreduzida, $vrhsreduzida, 
        $dsincidevenperder, $qtmesretrocmult, $qtmesretrocsemben, $dsafastamento1, $idgeradescafast1, $dsafastamento2, $qtmesmaxafast2, $idgeradescafast2, $dsafastamento3
    ){
        $beneficiocct = Repositories::VAB_BENEFICIOCCT;
        
        $novo = new $beneficiocct;
        $novo->setNrcadastrocct($nrcadastrocct);
        $novo->setNrtpbeneficio($nrtpbeneficio);
        $novo->setNridademaxsubfilhos($nridademaxsubfilhos);
        $novo->setSexosubsidiofilho($sexosubsidiofilho);
        $novo->setNridademaxsubdep($nridademaxsubdep);
        $novo->setSexosubsidiodep($sexosubsidiodep);
        $novo->setNrevetitularvinc($nrevetitularvinc);
        $novo->setNrtipoparticipatitular($nrtipoparticipatitular);
        $novo->setNrtabfaixasaltit($nrtabfaixasaltit);
        $novo->setVrtitularsind($vrtitularsind);
        $novo->setVrtetotitularsind($vrtetotitularsind);
        $novo->setVrpisotitularsind($vrpisotitularsind);
        $novo->setNrevedepevinc($nrevedepevinc);
        $novo->setNrtipoparticipadep($nrtipoparticipadep);
        $novo->setNrtabfaixasaldep($nrtabfaixasaldep);
        $novo->setVrdepsind($vrdepsind);
        $novo->setVrpisodepsind($vrpisodepsind);
        $novo->setVrtetodepsind($vrtetodepsind);
        $novo->setIdativo($idativo);

        $novo->setNreventomensa($nreventomensa);
        $novo->setNreventomensadep($nreventomensadep);
        $novo->setVrtetotitularmens($vrtetotitularmens);
        $novo->setVrpisotitularmens($vrpisotitularmens);
        $novo->setVrlinearbeneficio($vrlinearbeneficio);
        $novo->setVrlinearbeneficiodep($vrlinearbeneficiodep);
        $novo->setIdpropadmis($idpropadmis);
        $novo->setIdpropresc($idpropresc);
        $novo->setQtdiasminmes($qtdiasminmes);
        $novo->setQtdiasmaxfaltas($qtdiasmaxfaltas);
        $novo->setQtdiasmaxatest($qtdiasmaxatest);
        $novo->setQtmesmaxafast($qtmesmaxafast);
        $novo->setVrmultiplicador($vrmultiplicador);
        $novo->setDsvinculoempreg($dsvinculoempreg);
        $novo->setDsincidevento($dsincidevento);
        $novo->setVrfixacresdesc($vrfixacresdesc);
        $novo->setVrperacrescdesc($vrperacrescdesc);
        $novo->setIdnaogerbenvincexp($idnaogerbenvincexp);
        $novo->setIdnaogerabenperexp($idnaogerabenperexp);
        $novo->setIdnaogerabenresc($idnaogerabenresc);
        
        $novo->setVrparticipatitular($vrparticipatitular);
        $novo->setVrpisotitular($vrpisotitular);
        $novo->setVrtetotitular($vrtetotitular);
        $novo->setVrparticipadepe($vrparticipadepe);
        $novo->setVrpisodep($vrpisodep);
        $novo->setVrtetodep($vrtetodep);
        $novo->setQtmaxhsreduzida($qtmaxhsreduzida);
        $novo->setVrhsreduzida($vrhsreduzida);
        $novo->setDsincidevenperder($dsincidevenperder);
        $novo->setQtmesretrocmult($qtmesretrocmult);
        $novo->setQtmesretrocsemben($qtmesretrocsemben);
        $novo->setDsafastamento1($dsafastamento1);
        $novo->setIdgeradescafast1($idgeradescafast1);
        $novo->setDsafastamento2($dsafastamento2);
        $novo->setQtmesmaxafast2($qtmesmaxafast2);
        $novo->setIdgeradescafast2($idgeradescafast2);
        $novo->setDsafastamento3($dsafastamento3);
        
        $novo->setNrorg($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtinclusao(DateUtil::getDataAtual());
        $novo->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $novo->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtultatu(DateUtil::getDataAtual());
        $novo->setCdoperultatu($this->hcmParameters->getCdoperador());
        $novo->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        
        $novo->setNrbeneficiocct(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'VAB_BENEFICIOCCT', 1, 12, true));
        
        $this->entityManager->persist($novo);
        $this->entityManager->flush();
        
        return $novo;
    }
    
    public function recadastro($dataset){
        $nrorgAntigo = isset($dataset['NRORGORIG']) ? $dataset['NRORGORIG'] : $dataset['NRORG'];
        $codAntigo = $dataset['NRCADASTROCCT'];
        $codNovo = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'FPA_CADASTROCCT', 1, 12, true);
        
        $this->CCTRepository->setCCT(
            array(
                "P_NRORG" => $dataset["NRORG"],
                "P_NRCADASTROCCT" => $codNovo,
                "P_IDATIVO" => $dataset["IDATIVO"],
                "P_NRESTRUTURAM" => $dataset["NRESTRUTURAM"],
                "P_DTANOBASECCT" => $dataset["DTANOBASECCT"],
                "P_DTINIVIGENCIACCT" => $dataset["DTINIVIGENCIACCT"],
                "P_DTFINVIGENCIACCT" => $dataset["DTFINVIGENCIACCT"],
                "P_DTINCLUSAO" => $this->hcmParameters->getDataAtual(false),
                "P_CDOPERINCLUSAO" => $this->hcmParameters->getCdoperador(),
                "P_NRORGINCLUSAO" => $this->hcmParameters->getNrorgTrabalho(),
                "P_DTULTATU" => $this->hcmParameters->getDataAtual(false),
                "P_CDOPERULTATU" => $this->hcmParameters->getCdoperador(),
                "P_NRORGULTATU" => $this->hcmParameters->getNrorgTrabalho()
            )
        );
        
        $itens = $this->CCTRepository->getItens($nrorgAntigo,$codAntigo);
        foreach($itens as $item){
            $params = array(
                "P_NRORG" => $dataset["NRORG"],
                "P_NRCADASTROCCT" => $codNovo,
                "P_NRITCADASTROCCT" => \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'FPA_ITCADASTROCCT ', 1, 12, true),
                "P_NRTIPOITEMCCT" => isset($item["NRTIPOITEMCCT"])?$item["NRTIPOITEMCCT"]:null,
                "P_DSITEMCCT" => isset($item["DSITEMCCT"])?$item["DSITEMCCT"]:null,
                "P_DSLEGISLACAOITCCT" => isset($item["DSLEGISLACAOITCCT"])?$item["DSLEGISLACAOITCCT"]:null,
                "P_NROCUPACAOM" => isset($item["NROCUPACAOM"])?$item["NROCUPACAOM"]:null,
                "P_NRESCALATRABM" => isset($item["NRESCALATRABM"])?$item["NRESCALATRABM"]:null,
                "P_NRSITUFUNCM" => isset($item["NRSITUFUNCM"])?$item["NRSITUFUNCM"]:null,
                "P_NRTPDEMISSAO" => isset($item["NRTPDEMISSAO"])?$item["NRTPDEMISSAO"]:null,
                "P_NREVENTOM" => isset($item["NREVENTOM"])?$item["NREVENTOM"]:null,
                "P_NRFAIXATABFOLHA" => isset($item["NRFAIXATABFOLHA"])?$item["NRFAIXATABFOLHA"]:null,
                "P_NRVALORREFERENCIAM" => isset($item["NRVALORREFERENCIAM"])?$item["NRVALORREFERENCIAM"]:null,
                "P_VRPISOITCCT" => isset($item["VRPISOITCCT"])?$item["VRPISOITCCT"]:null,
                "P_VRTETOITCCT" => isset($item["VRTETOITCCT"])?$item["VRTETOITCCT"]:null,
                "P_DTINIITEMCCT" => isset($item["DTINIITEMCCT"])?$item["DTINIITEMCCT"]:null,
                "P_DTFINITEMCCT" => isset($item["DTFINITEMCCT"])?$item["DTFINITEMCCT"]:null,
                "P_VRPERCENTUALITCCT" => isset($item["VRPERCENTUALITCCT"])?$item["VRPERCENTUALITCCT"]:null,
                "P_VRITEMCCT" => isset($item["VRITEMCCT"])?$item["VRITEMCCT"]:null,
                "P_DSINIINTERVALOCCT" => isset($item["DSINIINTERVALOCCT"])?$item["DSINIINTERVALOCCT"]:null,
                "P_DSFININTERVALOCCT" => isset($item["DSFININTERVALOCCT"])?$item["DSFININTERVALOCCT"]:null,
                "P_VRIDADEMINIMACCT" => isset($item["VRIDADEMINIMACCT"])?$item["VRIDADEMINIMACCT"]:null,
                "P_VRIDADEMAXIMACCT" => isset($item["VRIDADEMAXIMACCT"])?$item["VRIDADEMAXIMACCT"]:null,
                "P_QTDEMESESITCCT" => isset($item["QTDEMESESITCCT"])?$item["QTDEMESESITCCT"]:null,
                "P_QTDEANOMINCCT" => isset($item["QTDEANOMINCCT"])?$item["QTDEANOMINCCT"]:null,
                "P_QTDEANOMAXCCT" => isset($item["QTDEANOMAXCCT"])?$item["QTDEANOMAXCCT"]:null,
                "P_QTDIASESTABITCCT" => isset($item["QTDIASESTABITCCT"])?$item["QTDIASESTABITCCT"]:null,
                "P_DTINCLUSAO" => $this->hcmParameters->getDataAtual(false),
                "P_CDOPERINCLUSAO" => $this->hcmParameters->getCdoperador(),
                "P_NRORGINCLUSAO" => $this->hcmParameters->getNrorgTrabalho(),
                "P_DTULTATU" => $this->hcmParameters->getDataAtual(false),
                "P_CDOPERULTATU" => $this->hcmParameters->getCdoperador(),
                "P_NRORGULTATU" => $this->hcmParameters->getNrorgTrabalho()
            );
            $this->CCTRepository->setitemCCT($params);
        }

        $beneficios = $this->CCTRepository->getBeneficiosCCT($nrorgAntigo,$codAntigo);
        foreach($beneficios as $beneficio){
            $params = array(
                "P_NRORG" => intval($dataset["NRORG"]),
                "P_NRBENEFICIOCCT" => intval(\HCM\Util\NovoCodigo::geraCodigo($dataset['NRORG'], 'VAB_BENEFICIOCCT', 1, 12, true)),
                "P_NRCADASTROCCT" => $codNovo,
                "P_NRTPBENEFICIO" => isset($beneficio["NRTPBENEFICIO"]) && !empty($beneficio["NRTPBENEFICIO"])? intval($beneficio["NRTPBENEFICIO"]) : null,           
                "P_NRIDADEMAXSUBFILHOS" => isset($beneficio["NRIDADEMAXSUBFILHOS"]) && !empty($beneficio["NRIDADEMAXSUBFILHOS"])? intval($beneficio["NRIDADEMAXSUBFILHOS"]) : null,                                
                "P_SEXOSUBSIDIOFILHO" => isset($beneficio["SEXOSUBSIDIOFILHO"]) && !empty($beneficio["SEXOSUBSIDIOFILHO"])? $beneficio["SEXOSUBSIDIOFILHO"] : null,                                                
                "P_NRIDADEMAXSUBDEP" => isset($beneficio["NRIDADEMAXSUBDEP"]) && !empty($beneficio["NRIDADEMAXSUBDEP"])? intval($beneficio["NRIDADEMAXSUBDEP"]) : null,                                                                        
                "P_SEXOSUBSIDIODEP" => isset($beneficio["SEXOSUBSIDIODEP"]) && !empty($beneficio["SEXOSUBSIDIODEP"])? $beneficio["SEXOSUBSIDIODEP"] : null,                                                                                         
                "P_NREVETITULARVINC" => isset($beneficio["NREVETITULARVINC"]) && !empty($beneficio["NREVETITULARVINC"])? intval($beneficio["NREVETITULARVINC"]) : null,                                                                                                                 
                "P_NRTIPOPARTICIPATITULAR" => isset($beneficio["NRTIPOPARTICIPATITULAR"]) && !empty($beneficio["NRTIPOPARTICIPATITULAR"])? $beneficio["NRTIPOPARTICIPATITULAR"] : null,                                                                                                                           
                "P_NRTABFAIXASALTIT" => isset($beneficio["NRTABFAIXASALTIT"]) && !empty($beneficio["NRTABFAIXASALTIT"])? $beneficio["NRTABFAIXASALTIT"] : null,                                                                                                                                           
                "P_VRTITULARSIND" => isset($beneficio["VRTITULARSIND"]) && !empty($beneficio["VRTITULARSIND"])? $beneficio["VRTITULARSIND"] : null,                                                                                                                                                              
                "P_VRTETOTITULARSIND" => isset($beneficio["VRTETOTITULARSIND"]) && !empty($beneficio["VRTETOTITULARSIND"])? $beneficio["VRTETOTITULARSIND"] : null,                                                                                                                                                                             
                "P_VRPISOTITULARSIND" => isset($beneficio["VRPISOTITULARSIND"]) && !empty($beneficio["VRPISOTITULARSIND"])? $beneficio["VRPISOTITULARSIND"] : null,                                                                                                                                                                                            
                "P_NREVEDEPEVINC" => isset($beneficio["NREVEDEPEVINC"]) && !empty($beneficio["NREVEDEPEVINC"])? intval($beneficio["NREVEDEPEVINC"]) : null,                                                                                                                                                                                                                        
                "P_NRTIPOPARTICIPADEP" => isset($beneficio["NRTIPOPARTICIPADEP"]) && !empty($beneficio["NRTIPOPARTICIPADEP"])? $beneficio["NRTIPOPARTICIPADEP"] : null,                                                                                                                                                                                                                                       
                "P_NRTABFAIXASALDEP" => isset($beneficio["NRTABFAIXASALDEP"]) && !empty($beneficio["NRTABFAIXASALDEP"])? $beneficio["NRTABFAIXASALDEP"] : null,                                                                                                                                                                                                                                                        
                "P_VRDEPSIND" => isset($beneficio["VRDEPSIND"]) && !empty($beneficio["VRDEPSIND"])? $beneficio["VRDEPSIND"] : null,                                                                                                                                                                                                                                                                                
                "P_VRPISODEPSIND" => isset($beneficio["VRPISODEPSIND"]) && !empty($beneficio["VRPISODEPSIND"])? $beneficio["VRPISODEPSIND"] : null,                                                                                                                                                                                                                                                                                                   
                "P_VRTETODEPSIND" => isset($beneficio["VRTETODEPSIND"]) && !empty($beneficio["VRTETODEPSIND"])? $beneficio["VRTETODEPSIND"] : null,                                                                                                                                                                                                                                                                                                                      
                "P_IDATIVO" => isset($beneficio["IDATIVO"]) && !empty($beneficio["IDATIVO"])? $beneficio["IDATIVO"] : 'S',                                                                                                                                                                                                                                                                                                                      

                "P_NREVENTOMENSA" => isset($beneficio["NREVENTOMENSA"]) && !empty($beneficio["NREVENTOMENSA"])? $beneficio["NREVENTOMENSA"] : null,                                                                                                                                                                                                                                                                                                                      
                "P_NREVENTOMENSADEP" => isset($beneficio["NREVENTOMENSADEP"]) && !empty($beneficio["NREVENTOMENSADEP"])? $beneficio["NREVENTOMENSADEP"] : null,                                                                                                                                                                                                                                                                                                                      
                "P_VRTETOTITULARMENS" => isset($beneficio["VRTETOTITULARMENS"]) && !empty($beneficio["VRTETOTITULARMENS"])? $beneficio["VRTETOTITULARMENS"] : null,                                                                                                                                                                                                                                                                                                                      
                "P_VRPISOTITULARMENS" => isset($beneficio["VRPISOTITULARMENS"]) && !empty($beneficio["VRPISOTITULARMENS"])? $beneficio["VRPISOTITULARMENS"] : null,                                                                                                                                                                                                                                                                                                                      
                "P_VRLINEARBENEFICIO" => isset($beneficio["VRLINEARBENEFICIO"]) && !empty($beneficio["VRLINEARBENEFICIO"])? $beneficio["VRLINEARBENEFICIO"] : null,                                                                                                                                                                                                                                                                                                                      
                "P_VRLINEARBENEFICIODEP" => isset($beneficio["VRLINEARBENEFICIODEP"]) && !empty($beneficio["VRLINEARBENEFICIODEP"])? $beneficio["VRLINEARBENEFICIODEP"] : null,                                                                                                                                                                                                                                                                                                                      
                "P_IDPROPADMIS" => isset($beneficio["IDPROPADMIS"]) && !empty($beneficio["IDPROPADMIS"])? $beneficio["IDPROPADMIS"] : 'N',                                                                                                                                                                                                                                                                                                                      
                "P_IDPROPRESC" => isset($beneficio["IDPROPRESC"]) && !empty($beneficio["IDPROPRESC"])? $beneficio["IDPROPRESC"] : 'N',                                                                                                                                                                                                                                                                                                                      
                "P_QTDIASMINMES" => isset($beneficio["QTDIASMINMES"]) && !empty($beneficio["QTDIASMINMES"])? $beneficio["QTDIASMINMES"] : null,                                                                                                                                                                                                                                                                                                                      
                "P_QTDIASMAXFALTAS" => isset($beneficio["QTDIASMAXFALTAS"]) && !empty($beneficio["QTDIASMAXFALTAS"])? $beneficio["QTDIASMAXFALTAS"] : null,                                                                                                                                                                                                                                                                                                                      
                "P_QTDIASMAXATEST" => isset($beneficio["QTDIASMAXATEST"]) && !empty($beneficio["QTDIASMAXATEST"])? $beneficio["QTDIASMAXATEST"] : null,
                "P_QTMESMAXAFAST" => isset($beneficio["QTMESMAXAFAST"]) && !empty($beneficio["QTMESMAXAFAST"])? $beneficio["QTMESMAXAFAST"] : null,                                                                                                                                                                                                                                                                                                                      
                "P_VRMULTIPLICADOR" => isset($beneficio["VRMULTIPLICADOR"]) && !empty($beneficio["VRMULTIPLICADOR"])? $beneficio["VRMULTIPLICADOR"] : null,                                                                                                                                                                                                                                                                                                                      
                "P_DSVINCULOEMPREG" => isset($beneficio["DSVINCULOEMPREG"]) && !empty($beneficio["DSVINCULOEMPREG"])? $beneficio["DSVINCULOEMPREG"] : null,                                                                                                                                                                                                                                                                                                                      
                "P_DSINCIDEVENTO" => isset($beneficio["DSINCIDEVENTO"]) && !empty($beneficio["DSINCIDEVENTO"])? $beneficio["DSINCIDEVENTO"] : null,                                                                                                                                                                                                                                                                                                                      
                "P_VRFIXACRESDESC" => isset($beneficio["VRFIXACRESDESC"]) && !empty($beneficio["VRFIXACRESDESC"])? $beneficio["VRFIXACRESDESC"] : null, 
                "P_VRPERACRESCDESC" => isset($beneficio["VRPERACRESCDESC"]) && !empty($beneficio["VRPERACRESCDESC"])? $beneficio["VRPERACRESCDESC"] : null, 
                "P_IDNAOGERBENVINCEXP" => isset($beneficio["IDNAOGERBENVINCEXP"]) && !empty($beneficio["IDNAOGERBENVINCEXP"])? $beneficio["IDNAOGERBENVINCEXP"] : 'S',
                "P_IDNAOGERABENPEREXP" => isset($beneficio["IDNAOGERABENPEREXP"]) && !empty($beneficio["IDNAOGERABENPEREXP"])? $beneficio["IDNAOGERABENPEREXP"] : 'S',                                                                                                                                                                                                                                                                                                                      
                "P_IDNAOGERABENRESC" => isset($beneficio["IDNAOGERABENRESC"]) && !empty($beneficio["IDNAOGERABENRESC"])? $beneficio["IDNAOGERABENRESC"] : 'S',
                
                "P_VRPARTICIPATITULAR" => isset($beneficio['VRPARTICIPATITULAR']) && !empty($beneficio['VRPARTICIPATITULAR']) ? floatval($beneficio['VRPARTICIPATITULAR']) : null,
                "P_VRPISOTITULAR" => isset($beneficio['VRPISOTITULAR']) && !empty($beneficio['VRPISOTITULAR']) ? floatval($beneficio['VRPISOTITULAR']) : null,
                "P_VRTETOTITULAR" => isset($beneficio['VRTETOTITULAR']) && !empty($beneficio['VRTETOTITULAR']) ? floatval($beneficio['VRTETOTITULAR']) : null,
                "P_VRPARTICIPADEPE" => isset($beneficio['VRPARTICIPADEPE']) && !empty($beneficio['VRPARTICIPADEPE']) ? floatval($beneficio['VRPARTICIPADEPE']) : null,
                "P_VRPISODEP" => isset($beneficio['VRPISODEP']) && !empty($beneficio['VRPISODEP']) ? floatval($beneficio['VRPISODEP']) : null,
                "P_VRTETODEP" => isset($beneficio['VRTETODEP']) && !empty($beneficio['VRTETODEP']) ? floatval($beneficio['VRTETODEP']) : null,
                "P_QTMAXHSREDUZIDA" => isset($beneficio['QTMAXHSREDUZIDA']) && !empty($beneficio['QTMAXHSREDUZIDA']) ? intval($beneficio['QTMAXHSREDUZIDA']) : null,
                "P_VRHSREDUZIDA" => isset($beneficio['VRHSREDUZIDA']) && !empty($beneficio['VRHSREDUZIDA']) ? floatval($beneficio['VRHSREDUZIDA']) : null,
                "P_DSINCIDEVENPERDER" => isset($beneficio['DSINCIDEVENPERDER']) && !empty($beneficio['DSINCIDEVENPERDER']) ? $beneficio['DSINCIDEVENPERDER'] : null,
                "P_QTMESRETROCMULT" => isset($beneficio['QTMESRETROCMULT']) && !empty($beneficio['QTMESRETROCMULT']) ? intval($beneficio['QTMESRETROCMULT']) : null,
                "P_QTMESRETROCSEMBEN" => isset($beneficio['QTMESRETROCSEMBEN']) && !empty($beneficio['QTMESRETROCSEMBEN']) ? intval($beneficio['QTMESRETROCSEMBEN']) : null,
                "P_DSAFASTAMENTO1" => isset($beneficio['DSAFASTAMENTO1']) && !empty($beneficio['DSAFASTAMENTO1']) ? $beneficio['DSAFASTAMENTO1'] : null,
                "P_IDGERADESCAFAST1" => isset($beneficio['IDGERADESCAFAST1']) && !empty($beneficio['IDGERADESCAFAST1']) ? $beneficio['IDGERADESCAFAST1'] : 'N',
                "P_DSAFASTAMENTO2" => isset($beneficio['DSAFASTAMENTO2']) && !empty($beneficio['DSAFASTAMENTO2']) ? $beneficio['DSAFASTAMENTO2'] : null,
                "P_QTMESMAXAFAST2" => isset($beneficio['QTMESMAXAFAST2']) && !empty($beneficio['QTMESMAXAFAST2']) ? intval($beneficio['QTMESMAXAFAST2']) : null,
                "P_IDGERADESCAFAST2" => isset($beneficio['IDGERADESCAFAST2']) && !empty($beneficio['IDGERADESCAFAST2']) ? $beneficio['IDGERADESCAFAST2'] : 'N',
                "P_DSAFASTAMENTO3" => isset($beneficio['DSAFASTAMENTO3']) && !empty($beneficio['DSAFASTAMENTO3']) ? $beneficio['DSAFASTAMENTO3'] : null,

                "P_DTINCLUSAO" => $this->hcmParameters->getDataAtual(false),
                "P_CDOPERINCLUSAO" => $this->hcmParameters->getCdoperador(),
                "P_NRORGINCLUSAO" => $this->hcmParameters->getNrorgTrabalho(),
                "P_DTULTATU" => $this->hcmParameters->getDataAtual(false),
                "P_CDOPERULTATU" => $this->hcmParameters->getCdoperador(),
                "P_NRORGULTATU" => $this->hcmParameters->getNrorgTrabalho()
            );
            $this->CCTRepository->setBeneficioCCT($params);
        }
    }
    
    public function validaCamposVaziosBeneficioCCT(&$row){
        $row['NRORG'] = isset($row['NRORG']) && !empty($row['NRORG']) ? $row['NRORG'] : $this->hcmParameters->getNrorgTrabalho();
        $row['NREVENTOMENSA'] = isset($row['NREVENTOMENSA']) && !empty($row['NREVENTOMENSA']) ? intval($row['NREVENTOMENSA']) : null;
        $row['NREVENTOMENSADEP'] = isset($row['NREVENTOMENSADEP']) && !empty($row['NREVENTOMENSADEP']) ? intval($row['NREVENTOMENSADEP']) : null;
        $row['NRIDADEMAXSUBFILHOS'] = isset($row['NRIDADEMAXSUBFILHOS']) && !empty($row['NRIDADEMAXSUBFILHOS']) ? intval($row['NRIDADEMAXSUBFILHOS']) : null;
        $row['SEXOSUBSIDIOFILHO'] = isset($row['SEXOSUBSIDIOFILHO']) && !empty($row['SEXOSUBSIDIOFILHO']) ? $row['SEXOSUBSIDIOFILHO'] : null;
        $row['NRIDADEMAXSUBDEP'] = isset($row['NRIDADEMAXSUBDEP']) && !empty($row['NRIDADEMAXSUBDEP']) ? $row['NRIDADEMAXSUBDEP'] : null;
        $row['SEXOSUBSIDIODEP'] = isset($row['SEXOSUBSIDIODEP']) && !empty($row['SEXOSUBSIDIODEP']) ? $row['SEXOSUBSIDIODEP'] : null;
        $row['NREVETITULARVINC'] = isset($row['NREVETITULARVINC']) && !empty($row['NREVETITULARVINC']) ? $row['NREVETITULARVINC'] : null;
        $row['NRTIPOPARTICIPATITULAR'] = isset($row['NRTIPOPARTICIPATITULAR']) && !empty($row['NRTIPOPARTICIPATITULAR']) ? $row['NRTIPOPARTICIPATITULAR'] : null;
        $row['NRTABFAIXASALTIT'] = isset($row['NRTABFAIXASALTIT']) && !empty($row['NRTABFAIXASALTIT']) ? $row['NRTABFAIXASALTIT'] : null;
        $row['VRTITULARSIND'] = isset($row['VRTITULARSIND']) && !empty($row['VRTITULARSIND']) ? floatval($row['VRTITULARSIND']) : 0;
        $row['VRTETOTITULARSIND'] = isset($row['VRTETOTITULARSIND']) && !empty($row['VRTETOTITULARSIND']) ? floatval($row['VRTETOTITULARSIND']) : null;
        $row['VRPISOTITULARSIND'] = isset($row['VRPISOTITULARSIND']) && !empty($row['VRPISOTITULARSIND']) ? floatval($row['VRPISOTITULARSIND']) : null;
        $row['NREVEDEPEVINC'] = isset($row['NREVEDEPEVINC']) && !empty($row['NREVEDEPEVINC']) ? $row['NREVEDEPEVINC'] : null;
        $row['NRTIPOPARTICIPADEP'] = isset($row['NRTIPOPARTICIPADEP']) && !empty($row['NRTIPOPARTICIPADEP']) ? $row['NRTIPOPARTICIPADEP'] : null;
        $row['NRTABFAIXASALDEP'] = isset($row['NRTABFAIXASALDEP']) && !empty($row['NRTABFAIXASALDEP']) ? $row['NRTABFAIXASALDEP'] : null;
        $row['VRDEPSIND'] = isset($row['VRDEPSIND']) && !empty($row['VRDEPSIND']) ? floatval($row['VRDEPSIND']) : 0;
        $row['VRPISODEPSIND'] = isset($row['VRPISODEPSIND']) && !empty($row['VRPISODEPSIND']) ? floatval($row['VRPISODEPSIND']) : null;
        $row['VRTETODEPSIND'] = isset($row['VRTETODEPSIND']) && !empty($row['VRTETODEPSIND']) ? floatval($row['VRTETODEPSIND']) : null;
        $row['VRHSREDUZIDA'] = isset($row['VRHSREDUZIDA']) && !empty($row['VRHSREDUZIDA']) ? floatval($row['VRHSREDUZIDA']) : null;

        $row['VRPARTICIPATITULAR'] = isset($row['VRPARTICIPATITULAR']) && !empty($row['VRPARTICIPATITULAR']) ? floatval($row['VRPARTICIPATITULAR']) : 0;
        $row['VRPISOTITULAR'] = isset($row['VRPISOTITULAR']) && !empty($row['VRPISOTITULAR']) ? floatval($row['VRPISOTITULAR']) : null;
        $row['VRTETOTITULAR'] = isset($row['VRTETOTITULAR']) && !empty($row['VRTETOTITULAR']) ? floatval($row['VRTETOTITULAR']) : null;
        $row['VRPARTICIPADEPE'] = isset($row['VRPARTICIPADEPE']) && !empty($row['VRPARTICIPADEPE']) ? floatval($row['VRPARTICIPADEPE']) : 0;
        $row['VRPISODEP'] = isset($row['VRPISODEP']) && !empty($row['VRPISODEP']) ? floatval($row['VRPISODEP']) : null;
        $row['VRTETODEP'] = isset($row['VRTETODEP']) && !empty($row['VRTETODEP']) ? floatval($row['VRTETODEP']) : null;
        $row['QTMAXHSREDUZIDA'] = isset($row['QTMAXHSREDUZIDA']) && !empty($row['QTMAXHSREDUZIDA']) ? intval($row['QTMAXHSREDUZIDA']) : null;
        $row['VRHSREDUZIDA'] = isset($row['VRHSREDUZIDA']) && !empty($row['VRHSREDUZIDA']) ? floatval($row['VRHSREDUZIDA']) : null;
        $row['DSINCIDEVENPERDER'] = isset($row['DSINCIDEVENPERDER']) && !empty($row['DSINCIDEVENPERDER']) ? $row['DSINCIDEVENPERDER'] : null;
        $row['QTMESRETROCMULT'] = isset($row['QTMESRETROCMULT']) && !empty($row['QTMESRETROCMULT']) ? intval($row['QTMESRETROCMULT']) : null;
        $row['QTMESRETROCSEMBEN'] = isset($row['QTMESRETROCSEMBEN']) && !empty($row['QTMESRETROCSEMBEN']) ? intval($row['QTMESRETROCSEMBEN']) : null;
        $row['DSAFASTAMENTO1'] = isset($row['DSAFASTAMENTO1']) && !empty($row['DSAFASTAMENTO1']) ? $row['DSAFASTAMENTO1'] : null;
        $row['IDGERADESCAFAST1'] = isset($row['IDGERADESCAFAST1']) && !empty($row['IDGERADESCAFAST1']) ? $row['IDGERADESCAFAST1'] : null;
        $row['DSAFASTAMENTO2'] = isset($row['DSAFASTAMENTO2']) && !empty($row['DSAFASTAMENTO2']) ? $row['DSAFASTAMENTO2'] : null;
        $row['QTMESMAXAFAST2'] = isset($row['QTMESMAXAFAST2']) && !empty($row['QTMESMAXAFAST2']) ? intval($row['QTMESMAXAFAST2']) : null;
        $row['IDGERADESCAFAST2'] = isset($row['IDGERADESCAFAST2']) && !empty($row['IDGERADESCAFAST2']) ? $row['IDGERADESCAFAST2'] : null;
        $row['DSAFASTAMENTO3'] = isset($row['DSAFASTAMENTO3']) && !empty($row['DSAFASTAMENTO3']) ? $row['DSAFASTAMENTO3'] : null;
        
        $row['IDATIVO'] = isset($row['IDATIVO']) && !empty($row['IDATIVO']) ? $row['IDATIVO'] : "S";
        /*$row['DTINCLUSAO'] = isset($row['DTINCLUSAO']) && !empty($row['DTINCLUSAO']) ? $row['DTINCLUSAO'] : $this->hcmParameters->getDataAtual();
        $row['DTULTATU'] = isset($row['DTULTATU']) && !empty($row['DTULTATU']) ? $row['DTULTATU'] : $this->hcmParameters->getDataAtual();
        $row['NRORGINCLUSAO'] = isset($row['NRORGINCLUSAO']) && !empty($row['NRORGINCLUSAO']) ? $row['NRORGINCLUSAO'] : $this->hcmParameters->getNrorgTrabalho();
        $row['NRORGULTATU'] = isset($row['NRORGULTATU']) && !empty($row['NRORGULTATU']) ? $row['NRORGULTATU'] : $this->hcmParameters->getNrorgTrabalho();
        $row['CDOPERINCLUSAO'] = isset($row['CDOPERINCLUSAO']) && !empty($row['CDOPERINCLUSAO']) ? $row['CDOPERINCLUSAO'] : $this->hcmParameters->getCdoperador();
        $row['CDOPERULTATU'] = isset($row['CDOPERULTATU']) && !empty($row['CDOPERULTATU']) ? $row['CDOPERULTATU'] : $this->hcmParameters->getCdoperador();*/
    }
    
    public function validarDeleteItemCCT($dataset) {
        try {
            $sql = $this->entityManager->getConnection()->prepare("
                SELECT * 
                FROM FPA_ITCADASTROCCT  
                WHERE NRORG = :P_NRORG AND
                NRCADASTROCCT = :P_NNRCADASTROCCT  
            ");
            $sql->execute(
                array(
                    "P_NRORG"=>$dataset['NRORG'],
                    "P_NNRCADASTROCCT"=>$dataset['NRCADASTROCCT']
                )   
            );
            $items = $sql->fetchAll();
            if(!empty($items)) {
                throw new \Exception("Existem itens relacionados a este registro, favor deleta-los.");
            }
         
        } catch (\Exception $e) {            
            throw $e;
        }
    }

    public function validarDeleteBeneficioCCT($dataset) {
        try {
            $sql = $this->entityManager->getConnection()->prepare("
                SELECT * 
                FROM VAB_BENEFICIOCCT  
                WHERE NRORG = :P_NRORG AND
                NRCADASTROCCT = :P_NNRCADASTROCCT  
            ");
            $sql->execute(
                array(
                    "P_NRORG"=>$dataset['NRORG'],
                    "P_NNRCADASTROCCT"=>$dataset['NRCADASTROCCT']
                )   
            );
            $items = $sql->fetchAll();
            if(!empty($items)) {
                throw new \Exception("Existem benefícios relacionados a este registro, favor deleta-los.");
            }
         
        } catch (\Exception $e) {            
            throw $e;
        }
    }
    
    public function verificarTpBeneficioJahCadastrado($nrorg, $nrCadastroCTT, $tpBeneficio, $nrBeneficioCCT = null){
        try {
            $wherePrimaryKey = "";
            
            $params = [
                "P_NRORG"=> $nrorg,
                "P_NRTPBENEFICIO" => $tpBeneficio,
                "P_NRCADASTROCCT" => $nrCadastroCTT,
            ];
            
            if($nrBeneficioCCT) {
                $wherePrimaryKey = " AND NRBENEFICIOCCT <> :P_NRBENEFICIOCCT ";
                $params["P_NRBENEFICIOCCT"] = $nrBeneficioCCT;
            }
            
            $sql = $this->entityManager->getConnection()->prepare("
                SELECT * 
                FROM VAB_BENEFICIOCCT  
                WHERE NRORG = :P_NRORG 
                AND NRCADASTROCCT = :P_NRCADASTROCCT
                AND NRTPBENEFICIO = :P_NRTPBENEFICIO
                $wherePrimaryKey
            ");
            $sql->execute($params);
            
            $beneficio = $sql->fetchAll();
            
            if(!empty($beneficio)) {
                throw new \Exception("Tipo de beneficio já cadastrado para esta CCT.");
            }
         
        } catch (\Exception $e) {            
            throw $e;
        }
        
    }

    public function validaCondicoesCCT($nrorg, $nrestruturaSindical,  $parametros) {
        try {
            $ccts = $this->entityManager->getRepository(Repositories::FPA_CADASTROCCT)->findBy(array('nrorg' => $nrorg, 'nrestruturam' => $nrestruturaSindical));
                if(!empty($ccts)) {
                    $salarioDentroCondicoesCCT = $this->validaItensCCT($ccts, $parametros);  
                    if(!$salarioDentroCondicoesCCT) {
                        return false;
                    }
                    return true;
                } else {
                    return true;
                }
        } catch (\Exception $e) {
            throw $e;
        }
       
    }

    private function validaItensCCT($ccts, $parametros)
    {  
        try {  
            $salarioDentroCondicoesCCT = [];
            foreach ($ccts as $cct ) { 
                $itensCCT = null;
                $itensCCT = $this->entityManager->getRepository(Repositories::FPA_ITCADASTROCCT)->findBy(array('nrorg' => $cct->getNrorg(), 'nrcadastrocct' => $cct->getNrcadastrocct()));
                if(!empty($itensCCT)) {
                    foreach ($itensCCT as $itemCCT) {
                        $salarioDentroCondicoesCCT[] = $this->salarioDentroCondicoesCCT($itemCCT,$parametros);
                    }
                }
            }  
            if(in_array(false, $salarioDentroCondicoesCCT)) {
                return false;
            } else {
                return true;
            }
        } catch (\Exception $e) {            
            throw $e;
        }
    }

    private function salarioDentroCondicoesCCT($itemCCT,$parametros)
    {  
        try {  
            $retorno = null;
            $salario = str_replace("." , "" , $parametros['VRSALARIO'] );
            
            if($itemCCT->getNrocupacaom()) {
                $nrocupacaoArray = explode(",", $itemCCT->getNrocupacaom());
                foreach($nrocupacaoArray as $chave => $nrocupacaom){
                    if(intval($nrocupacaom) == $parametros['NROCUPACAOM']) {
                        $ocupação = intval($nrocupacaom);
                    }
                }
            }
            
            if($itemCCT->getNrescalatrabm()) {
                $nrescalaArray = explode(",", $itemCCT->getNrescalatrabm());
                foreach($nrescalaArray as $chave => $nrescalam){
                    if(intval($nrescalam) == $parametros['NRESCALATRABM']) {
                        $escala = intval($nrescalam);
                    }
                }
            }
            
            if(isset($escala) && isset($ocupação)) {
                $salarioDentroCondicoesCCT =  floatval($salario) >=  $itemCCT->getVrpisoitcct() &&  floatval($salario) <= $itemCCT->getVrtetoitcct();
                if(!$salarioDentroCondicoesCCT) {
                    $retorno = false;
                    return $retorno;
                }  
            }
            $retorno = true;
            return $retorno;
        } catch (\Exception $e) {            
            throw $e;
        }
    }
}