<?php

namespace HCM\Geral\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria; 
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use HCM\Geral\Services\TipoContaPagarService;

class TipoContaPagarController extends Crud {

    protected $dataSourceName = 'ger_tipoctpagar';

    protected $parameterBagColumns = array('P_NRORG');

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters, TipoContaPagarService $tipoContaPagarService){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters = $hcmParameters;
        $this->tipoContaPagarService = $tipoContaPagarService;
        parent::__construct($dataSourceManager);
    }

    public function getTipoContaPagar (DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData); 
        $response->addDataSet($dataSet);
    }

    public function setTipoContaPagar (DTO\Request\DataSet $request, DTO\Response $response) {
        $existPrimaryKey = 0;
        foreach($request->getDataSet()->getRows() as &$row) {
            if($row['__is_new']){
                $existPrimaryKey = $this->tipoContaPagarService->validaRestricaoChavePrimaria($row['CDTPCTPAGAR'], $row["NRORG"]);
                if(is_numeric($row['CDTPCTPAGAR']))
                    $row['CDTPCTPAGAR'] = str_pad($row['CDTPCTPAGAR'], 2, "0", STR_PAD_LEFT);
            }
        }
        if($existPrimaryKey)
            $response->addNotification(new DTO\Response\Notification("DUPLICATE_PRIMARY_KEY_ERROR", DTO\Response\Notification::TYPE_ERROR));
        else 
            parent::save($request, $response);
    }
   
    public function delete(DTO\Request\DataSet $request, DTO\Response $response){
        parent::delete($request, $response);
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }

    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
}