<?php

namespace HCM\Util;
use HCM\Util\FPA;
use HCM\Util\Repositories;

class MsgCalculo {

    private static $instance = null;

    private $nrcalculofolha;
    private $nrvinculom;
    private $nrorg;
    private $mensagens;
    private $dsorigmsg;
    private $idstatus;
    private $idabort;

    /*Tipos de mensagens*/
    const ERRO = 'E';
    const ALERTA = 'A';

    /*Status do MsgCalculo*/
    const ID_PENDENTE = 0;
    const ID_COM_ALERTA = 1;
    const ID_COM_ERRO = 2;
    const ID_CONCLUIDO = 3;

    private function __construct() {
        $this->mensagens = array();
        $this->idstatus = self::ID_PENDENTE;
        $this->idabort = false;
        $this->msgCalc = Repositories::FPA_MSGCALCULO;
    }

    private function __clone() {

    }

    public static function getInstance() {
        if (self::$instance === null) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    public function clear()
    {
        self::$instance = null;
    }

    public function setDados($nrcalculofolha, $nrvinculom, $nrorg, $dsorigmsg = null, $mescompetencia = null)
    {
        $this->nrcalculofolha = $nrcalculofolha;
        $this->nrvinculom = $nrvinculom;
        $this->nrorg = $nrorg;
        $this->dsorigmsg = $dsorigmsg;
        $this->mescompetencia = $mescompetencia;
    }

    public function getDados()
    {
        return array(
            'NRCALCULOFOLHA' => $this->nrcalculofolha,
            'NRVINCULOM' => $this->nrvinculom,
            'NRORG' => $this->nrorg,
            'MENSAGENS' => $this->mensagens,
            'DSORIGMSG' => $this->dsorigmsg,
            'IDSTATUS' => $this->idstatus,
            'IDABORT' => $this->idabort,
        );
    }

    public function adicionaMensagem($mensagem, $tipo = self::ALERTA, $abort = false)
    {
        $this->mensagens[] = array(
            'MENSAGEM' => $mensagem,
            'TIPO' => $tipo,
            'DSORIGMSG' => $this->dsorigmsg
        );

        if ($tipo === self::ERRO) {
            $this->idstatus = self::ID_COM_ERRO;
        }
        elseif ($tipo === self::ALERTA) {
            if ($this->idstatus != self::ID_COM_ERRO) {
                $this->idstatus = self::ID_COM_ALERTA;
            }
        }
        

        $this->idabort = $abort === true ? $abort : $this->idabort;
    }

    public function retornaMensagens($tipo = null)
    {
        $result = array();

        if ($tipo === null) {
            $result = $this->mensagens;
        }
        else {
            foreach ($this->mensagens as $index => $msg) {
                if ($msg['TIPO'] === $tipo) {
                    $result[] = $this->mensagens[$index];
                }
            }
        }
        return $result;
    }
    
    public function limpaMensagens()
    {
        $this->mensagens = array();
    }

    public function salvaMensagens($limpaMensagem = true)
    {
        try {
                
            if($limpaMensagem){
                \Setforms2\Shared\Registry::getEntityManager()->getRepository(Repositories::FPA_MSGCALCULO)->limpaMsgCalculoVinculo($this->nrcalculofolha, $this->nrvinculom, $this->nrorg, $this->dsorigmsg);
            }
            if($this->mensagens){
                \Setforms2\Shared\Registry::getEntityManager()->beginTransaction();
                
                foreach ($this->mensagens as $mensagem) {
                    $item = new $this->msgCalc;
                    $nrmsgcalc = \HCM\Util\NovoCodigo::geraCodigo($this->nrorg, "FPA_MSGCALCULO", 1, 1, true, false);
    
                    if($this->mescompetencia){
                        $item->setDtinclusao($this->mescompetencia);
                        $item->setDtultatu($this->mescompetencia);
                    }
                    
                    $item->setNrmsgcalc($nrmsgcalc);
                    $item->setNrcalculofolha($this->nrcalculofolha);
                    $item->setNrvinculom($this->nrvinculom);
                    $item->setDescricao($mensagem['MENSAGEM']);
                    $item->setIdtipomsg($mensagem['TIPO']);
                    $item->setDsorigmsg($mensagem['DSORIGMSG']);
                    $item->setNrorg($this->nrorg);
                    $item->setCdoperinclusao(FPA::getCdOperador());
                    $item->setCdoperultatu(FPA::getCdOperador());
                    $item->setNrorginclusao($this->nrorg);
                    $item->setNrorgultatu($this->nrorg);
                    
                    \Setforms2\Shared\Registry::getEntityManager()->persist($item);
                    \Setforms2\Shared\Registry::getEntityManager()->flush($item);
                }
                
                \Setforms2\Shared\Registry::getEntityManager()->commit();
            }
            
        } catch (Exception $e) {
            \Setforms2\Shared\Registry::getEntityManager()->rollback();
            throw new \Exception('Erro ao cadastrar mensagem de cálculo [Vínculo:' . $this->nrvinculom . ' / Erro:' . $e->getMessage() . ']');
            return null;
        }
    }
}